@@ -1,7 +1,7 @@
 package App::AcmeCpanlists;
 
 our $DATE = '2016-11-17'; # DATE
-our $VERSION = '0.07'; # VERSION
+our $VERSION = '0.08'; # VERSION
 
 use 5.010001;
 use strict;
@@ -370,7 +370,8 @@ sub list_entries_all {
 
     my %args = @_;
 
-    my $is_single_list_mode = $args{_mode} && $args{_mode} eq 'single_list';
+    my $mode = $args{_mode} // '';
+    my $is_single_list_mode = $mode eq 'single_list';
 
     my $res;
     my $lists;
@@ -392,7 +393,9 @@ sub list_entries_all {
     $entity_field //= 'module_or_author';
 
     my @cols;
-    if ($args{detail}) {
+    if ($mode eq 'entry_lists') {
+        @cols = ('type', 'summary');
+    } elsif ($args{detail}) {
         push @cols, $entity_field;
         if ($is_single_list_mode) {
             push @cols, qw/summary rating/;
@@ -415,6 +418,7 @@ sub list_entries_all {
                         $entity_field => $n,
                         summary=>$e->{summary},
                         rating=>$e->{rating},
+                        (_list_ref => $list) x !!($mode eq 'entry_lists'),
                     };
                 }
             }
@@ -425,17 +429,19 @@ sub list_entries_all {
                             $entity_field => $n,
                             summary=>$e->{summary},
                             related=>1,
+                            (_list_ref => $list) x !!($mode eq 'entry_lists'),
                         };
                     }
                 }
             }
             for my $n (@{ $e->{"alternate_${type}s"} // [] }) {
                 if ($args{alternate} && $is_single_list_mode) {
-                    unless ($seen{$n}++) {
+                    unless ($seen{$n}++ && $is_single_list_mode) {
                         push @rows, {
                             $entity_field => $n,
                             summary=>$e->{summary},
                             alternate=>1,
+                            (_list_ref => $list) x !!($mode eq 'entry_lists'),
                         };
                     }
                 }
@@ -452,15 +458,36 @@ sub list_entries_all {
 
         my @filtered_rows;
         for my $row (@rows) {
-            next unless index(lc($row->{$entity_field}), $q) >= 0;
+            if ($args{query_type} && $args{query_type} eq 'exact-name') {
+                next unless lc($row->{$entity_field}) eq $q;
+            } else {
+                next unless index(lc($row->{$entity_field}), $q) >= 0;
+            }
             push @filtered_rows, $row;
         }
 
         @rows = @filtered_rows;
     }
 
+    # return entry lists
+    if ($mode eq 'entry_lists') {
+        no warnings 'uninitialized';
+        my @new_rows;
+        my %seen;
+        for my $row (@rows) {
+            my $list = $row->{_list_ref};
+            next if $seen{"$list->{type}|$list->{summary}"}++;
+            push @new_rows, {
+                type => $list->{type},
+                summary => $list->{summary},
+            };
+        }
+        @rows = @new_rows;
+        $args{detail} = 1; # TMP
+    }
+
     # group by entity
-    unless ($is_single_list_mode) {
+    if ($mode eq '') {
         my %occurrences; # key: entity name, value: n
         my %ratings;    # key: entity name, value = [rating, ...]
         for my $row (@rows) {
@@ -510,6 +537,26 @@ sub list_entries {
     list_entries_all(@_, _mode=>'single_list');
 }
 
+$SPEC{list_entry_lists} = {
+    v => 1.1,
+    summary => 'Find out in which lists a module or author is mentioned',
+    args_rels => {
+        %rels_filtering,
+    },
+    args => {
+        %args_filtering,
+        %arg_query,
+        %args_related_and_alternate,
+    },
+};
+sub list_entry_lists {
+    list_entries_all(
+        @_,
+        query_type => 'exact-name',
+        _mode => 'entry_lists',
+    );
+}
+
 1;
 # ABSTRACT: The Acme::CPANLists CLI (backend module)
 
@@ -525,7 +572,7 @@ App::AcmeCpanlists - The Acme::CPANLists CLI (backend module)
 
 =head1 VERSION
 
-This document describes version 0.07 of App::AcmeCpanlists (from Perl distribution App-AcmeCpanlists), released on 2016-11-17.
+This document describes version 0.08 of App::AcmeCpanlists (from Perl distribution App-AcmeCpanlists), released on 2016-11-17.
 
 =head1 SYNOPSIS
 
@@ -656,6 +703,48 @@ that contains extra information.
 Return value:  (any)
 
 
+=head2 list_entry_lists(%args) -> [status, msg, result, meta]
+
+Find out in which lists a module or author is mentioned.
+
+This function is not exported.
+
+Arguments ('*' denotes required arguments):
+
+=over 4
+
+=item * B<alternate> => I<bool>
+
+Filter based on whether entry is in alternate.
+
+=item * B<mentions_author> => I<str>
+
+=item * B<mentions_module> => I<str>
+
+=item * B<module> => I<str>
+
+=item * B<query>* => I<str>
+
+=item * B<related> => I<bool>
+
+Filter based on whether entry is in related.
+
+=item * B<type> => I<str>
+
+=back
+
+Returns an enveloped result (an array).
+
+First element (status) is an integer containing HTTP status code
+(200 means OK, 4xx caller error, 5xx function error). Second element
+(msg) is a string containing error message, or 'OK' if status is
+200. Third element (result) is optional, the actual result. Fourth
+element (meta) is called result metadata and is optional, a hash
+that contains extra information.
+
+Return value:  (any)
+
+
 =head2 list_lists(%args) -> [status, msg, result, meta]
 
 List CPAN lists.
